@@ -1776,9 +1776,8 @@ class App(Gtk.Application, TimerManager):
 		path = os.path.expanduser(box["path"])
 		if IS_WINDOWS:
 			# Don't attempt anything, use Windows Explorer on Windows
-			windows = os.environ("SystemRoot")
 			path = path.replace("/", "\\")
-			os.system('%s\\explorer.exe "%s"' % (windows, path))
+			os.startfile(path, 'explore')
 		else:
 			# Try to use any of following, known commands to
 			# display directory contents
